OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Betrachter",
    "Simple file viewer with slideshow for media" : "Einfacher Datei-Betrachter mit Diashow für Medien",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeigen Sie Ihre letzten Urlaubsfotos und -videos wie im Film, geben Sie einen Einblick in Ihren neuesten Roman direkt aus Ihrer Nextcloud, wählen Sie die besten GIF-Dateien aus Ihrer Sammlung dank der direkten Voransicht Ihrer favorisierten Dateien und viel mehr!",
    "Your browser does not support audio." : "Ihr Browser unterstützt kein Audio.",
    "Error loading {name}" : "Fehler beim Laden von {name}",
    "Your browser does not support videos." : "Ihr Browser unterstützt keine Videos.",
    "Open sidebar" : "Seitenleiste öffnen",
    "Delete" : "Löschen",
    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
    "View" : "Ansicht",
    "Your browser does not support the video tag." : "Ihr Browser unterstützt das Video-Tag nicht."
},
"nplurals=2; plural=(n != 1);");
